@@ -91,6 +91,7 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 			(u'tt',u'(.*t)tU',u'raamattu') ]),
 	(u'autio', u'-', [(None,u'(.*)',u'autio')]),
 	(u'kiiski', u'-', [(None,u'(.*)i',u'kiiski')]),
+	(u'siisti', u'-', [(None,u'(.*)i',u'siisti')]),
 	(u'risti', u'sw', [(None,u'(.*)i',u'risti'),
 			(u'pp',u'(pop)pi',u'pop'),
 			(u'pp',u'(.*p)pi',u'keppi'),
@@ -125,8 +126,10 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 			(u'p',u'(.*)pi',u'siipi'),
 			(u'k>',u'(.*i)ki',u'piki'),
 			(u'k>',u'(.*)ki',u'kaikki')]),
+	(u'veli', u'-', [(None,u'(.*el)i',u'veli')]),
 	(u'nalle', u'sw', [(None,u'(.*Ce)',u'nalle'),
 			 (None,u'(.*Cé)',u'nalle'),
+		         (None,u'(.*[iu]e)',u'nalle'),
 		         (u'tt',u'(.*t)te',u'atte'),
 		         (u'kk',u'(.*k)ke',u'nukke')]),
 	(u'kala', u'sw',   [(None,u'(.*)A',u'kala'),
@@ -157,12 +160,15 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 			(u't',u'(.*)tA',u'juhta'),
 			(u'k>',u'(.*i)kA',u'ikä'),
 			(u'k>',u'(.*)kA',u'hoikka')]),
+	(u'pitkä', u'-', [(None,u'(.*pi)tkA',u'pitkä')]),
+	(u'ruoka', u'-', [(None,u'(.*ru)oka',u'ruoka')]),
 	(u'poika', u'-', [(None,u'(.*po)ikA',u'poika')]),
 	(u'matala', u'-', [(None,u'(.*C)A',u'matala')]),
 	(u'asema', u'sw',  [(None,u'(.*)A',u'asema'),
 			(u'nt',u'(.*n)tA',u'emäntä')]),
 	(u'kulkija', u'-', [(None,u'(.*i)jA',u'kulkija'),
 			(None,u'(.*)A',u'apila')]),
+	(u'video', u'-', [(None,u'(.*deO)',u'video')]),
 	(u'karahka', u'sw', [(None,u'(.*)A',u'karahka'),
 			(u'tt',u'(.*t)tA',u'savotta'),
 			(u'pp',u'(.*p)pA',u'ulappa'),
@@ -170,7 +176,6 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 		        (u'nt',u'(.*n)tA',u'veranta')]),
 	(u'apaja', u'-', [(None,u'(.*C)A',u'apaja')]),
 	(u'peruna', u'-', [(None,u'(.*C)A',u'peruna')]),
-	(u'herttua', u'-', [(None,u'(.*tU)A',u'herttua')]),
 	(u'korkea', u'-', [(None,u'(.*C)eA',u'korkea'),
 		         (None,u'(.*O)A',u'ainoa')]),
 	(u'suurempi', u'sw', [(u'mp',u'(.*V)mpi',u'suurempi')]),
@@ -196,7 +201,7 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 		         (u'v',u'(.*)vAl',u'taival'),
 		         (u'>k',u'(.*)en',u'säen')]),
 	(u'rosé', u'-', [(None,u'(.*V)',u'rosé')]),
-	(u'parfait', u'-', [(None,u'(.*VC)',u'parfait')]),
+	(u'parfait', u'-', [(None,u'(.*)',u'parfait')]),
 	(u'huuli', u'-', [(None,u'(.*C)i',u'tuohi')]),
 	(u'meri', u'-', [(None,u'(.*er)i',u'meri')]),
 	(u'tuohi', u'-', [(None,u'(.*C)i',u'lohi')]),
@@ -204,13 +209,14 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 	(u'pieni', u'-', [(None,u'(.*n)i',u'pieni')]),
 	(u'lumi', u'-', [(None,u'(.*V)mi',u'lumi')]),
 	(u'susi', u'-', [(None,u'(.*V)si',u'susi')]),
+	(u'tosi', u'-', [(None,u'(.*V)si',u'tosi')]),
 	(u'kansi', u'-', [(None,u'(.*n)si',u'kansi'),
 	                  (None,u'(.*r)si',u'hirsi'),
 		        (None,u'(.*l)si',u'jälsi')]),
 	(u'sisar', u'ws', [(None,u'(.*CVC)',u'sisar'),
 		         (u't',u'(.*t)Ar',u'tytär'),
 		         (u'>k',u'(.*i)en',u'ien')]),
-	(u'uistin', u'ws', [(None,u'(.*i)n',u'uistin'),
+	(u'uistin', u'ws', [(None,u'(.*[iaä])n',u'uistin'),
 	                    (u'nn',u'(.*n)nin',u'vaimennin'),
 		          (u'll',u'(.*l)lin',u'sivellin'),
 		          (u'rr',u'(.*r)rin',u'kiharrin'),
@@ -227,7 +233,10 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 	(u'vastaus', u'-', [(None,u'(.*V)s',u'vastaus')]),
 	(u'kalleus', u'-', [(None,u'(.*VU)s',u'kalleus'),
 	                    (None,u'(.*vU)s',u'kalleus')]),
-	(u'vieras', u'ws', [(None,u'(.*A)s',u'vieras'),
+	(u'kaunis', u'-', [(None,u'(.*C)is',u'kaunis')]),
+	(u'vieras', u'ws', [(None,u'(.*[lmr]i[aä])s',u'antelias'),
+		            (None,u'(.*il[aä])s',u'antelias'),
+		            (None,u'(.*A)s',u'vieras'),
 	                    (None,u'(.*)is',u'kauris'),
 			(None,u'(.*e)s',u'kirves'),
 	                    (u'nn',u'(.*n)nAs',u'kinnas'),
@@ -248,6 +257,7 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 	(u'iäkäs', u'ws', [(u'k',u'(.*k)As',u'iäkäs',[ADJ]),
 		         (u'k',u'(.*k)As',u'asiakas',[SUBST])]),
 	(u'ohut', u'-', [(None,u'(.*CU)t',u'airut')]),
+	(u'kevät', u'-', [(None,u'(.*A)t',u'kevät')]),
 	(u'mies', u'-', [(None,u'(.*mie)s',u'mies')]),
 	(u'kuollut', u'-', [(None,u'(.*C)Ut',u'kuollut')]),
 	(u'hame', u'ws', [(None,u'(.*e)',u'hame'),
@@ -261,8 +271,14 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 		        (u'v',u'(.*)ve',u'taive'),
 		        (u'k',u'(.*k)e',u'tarvike'),
 		        (u'>k',u'(.*V)e',u'tarvike'),
+		        (u'>k',u'(.*h)e',u'tarvike'),
 		        (u't',u'(.*Vt)e',u'vaate'),
+		        (u't',u'(.*lt)e',u'vaate'),
 		        (u't',u'(.*rt)e',u'vaate')]),
+	(u'tie', u'-', [(None,u'(.*t)ie',u'tie')]),
+	(u'lapsi', u'-', [(None,u'(.*)psi',u'lapsi')]),
+	(u'hapsi', u'-', [(None,u'(.*)psi',u'hapsi')]),
+	(u'veitsi', u'-', [(None,u'(.*)tsi',u'veitsi')]),
 	# Verbs
 	(u'punoa', u'sw', [(None,u'(.*)A',u'punoa'),
 	                   (u'mp',u'(.*m)pUA',u'ampua'),
@@ -329,7 +345,7 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 			(u'k>',u'(.*)kAA',u'jakaa'),
 			(u't',u'(.*)tAA',u'raataa')]),
 	(u'kaikaa', u'-', [(None,u'(.*C)AA',u'kapsaa')]),
-	(u'soutaa', u'sw', [(u't',u'(.*V)tAA',u'soutaa')]),
+	(u'soutaa', u'sw', [(u't',u'(.*)tAA',u'soutaa')]),
 	(u'laskea', u'sw', [(None,u'(.*C)eA',u'laskea'),
 	                    (u'nk',u'(.*n)keA',u'tunkea'),
 			(u't',u'(.*)teA',u'kutea'),
@@ -352,6 +368,7 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 			(u'k>',u'(.*i)kiA',u'poikia'),
 			(u'k>',u'(.*)kiA',u'loikkia')]),
 	(u'voida', u'ws', [(u't',u'(.*)idA',u'voida')]),
+	(u'käydä', None, [(None,u'(.*)UdA',u'käydä')]),
 	(u'kanavoida', u'ws', [(u't',u'(.*O)idA',u'kanavoida')]),
 	(u'saada', u'-', [(None,u'(.*CA)AdA',u'saada'),
 	                  (None,u'(.*CU)UdA',u'myydä')]),
@@ -364,6 +381,7 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 			   (u'v',u'(.*)vistA',u'vavista'),
 			   (u'ng',u'(.*n)gAistA',u'rangaista')]),
 	(u'mennä', u'-', [(None,u'(.*n)nA',u'mennä')]),
+	(u'purra', u'-', [(None,u'(.*r)rA',u'purra')]),
 	(u'katsella', u'ws', [(None,u'(.*el)lA',u'katsella'),
 			(None,u'(.*eil)lA',u'katsella'),
 			(None,u'(.*Vil)lA',u'arvailla'),
@@ -425,7 +443,7 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 			(u'k',u'(.*k)AtA',u'pakata'),
 			(u'p',u'(.*p)AtA',u'pompata'),
 			(u'>k',u'(.*)AtA',u'taata')]),
-	(u'katketa', u'ws', [(None,u'(.*e)tA',u'katketa'),
+	(u'katketa', u'ws', [(None,u'(.*[oe])tA',u'katketa'),
 	                     (u'mm',u'(.*m)metA',u'kammeta'),
 			 (u'ng',u'(.*n)getA',u'langeta'),
 			 (u't',u'(.*t)OtA',u'lotota'),
@@ -446,7 +464,12 @@ modern_classmap = [(u'valo', u'sw', [(None,u'(.*)',u'valo'),
 			(u'd',u'(.*)dOtA',u'kadota'),
 			(u'>k',u'(.*)OtA',u'laota')]),
 	(u'kihistä', u'-', [(None,u'(.*C)istA',u'kihistä')]),
-	(u'kitistä', u'-', [(None,u'(.*C)istA',u'kitistä')])
+	(u'kitistä', u'-', [(None,u'(.*C)istA',u'kitistä')]),
+	(u'rakentaa', u'-', [(None,u'(.*n)tAA',u'rakentaa')]),
+	(u'taitaa', u'-', [(None,u'(.*)tAA',u'taitaa')]),
+	(u'juosta', u'-', [(None,u'(.*V)stA',u'juosta')]),
+	(u'nähdä', u'-', [(None,u'(.*)hdA',u'nähdä')]),
+	(u'kevetä', u'-', [(None,u'(.*)vetA',u'kevetä')])
 	]
 
 def compileClassmapREs(inputClassmap):
