@@ -65,11 +65,39 @@ def check_usage(word):
 			if usage in OPTIONS["extra-usage"]: return True
 	return False
 
+def get_prefix_jatko(word):
+	flags = generate_lex_common.get_flags_from_group(word, u"compounding")
+	prefixJatko = u""
+	for flag in flags:
+		if flag in [u"eln", u"ell", u"elt", u"eltj"]:
+			if (len(prefixJatko) > 0):
+				prefixJatko = prefixJatko + u" + "
+			prefixJatko = prefixJatko + u"@" + flag
+	return prefixJatko
+
+def get_adverb_jatko(word):
+	flags = generate_lex_common.get_flags_from_group(word, u"inflection")
+	prefixJatko = u"loppu"
+	for flag in flags:
+		if flag in [u"liitesana"]:
+			prefixJatko = prefixJatko + u", " + flag
+	return prefixJatko
+
+def get_additional_attributes(word):
+	flags = generate_lex_common.get_flags_from_group(word, u"compounding")
+	result = u""
+	if u"el_altark" in flags:
+		result = result + u", aluetta_tarkentava_etuliite: yes"
+	if u"geo_suffix" in flags:
+		result = result + u", paikannimen_jälkiliite: yes"
+	return result
+
 def handle_word(word):
 	global OPTIONS
 	global CLASSMAP
 	# Drop words that are not needed in the Voikko lexicon
-	if generate_lex_common.has_flag(word, "not_voikko"): return
+	if generate_lex_common.has_flag(word, "not_voikko") and "sukija" not in OPTIONS["extra-usage"]:
+		return
 	if not check_style(word): return
 	if not check_usage(word): return
 	if frequency(word) >= OPTIONS["frequency"] + 1: return
@@ -81,24 +109,38 @@ def handle_word(word):
 		if infclass.getAttribute("type") != "historical":
 			voikko_infclass = generate_lex_common.tValue(infclass)
 			break
-	if voikko_infclass == None: return
 	if voikko_infclass == u"poikkeava": return
 	
 	# Get the word classes
 	wordclasses = generate_lex_common.tValues(word.getElementsByTagName("classes")[0], "wclass")
+	if wordclasses[0] not in [u"interjection", u"prefix", u"abbreviation", u"adverb"] and voikko_infclass == None:
+		return
 	malaga_word_class = generate_lex_common.get_malaga_word_class(wordclasses)
 	if malaga_word_class == None: return
 	
+	baseformTags = word.getElementsByTagName("baseform")
+	if len(baseformTags) > 0:
+		baseform = generate_lex_common.tValue(baseformTags[0])
+	else:
+		baseform = None
+	
 	# Get malaga flags
 	malaga_flags = generate_lex_common.get_malaga_flags(word)
 	
 	# Get forced vowel type
-	forced_inflection_vtype = generate_lex_common.vowel_type(word.getElementsByTagName("inflection")[0])
+	if voikko_infclass == None and malaga_word_class != u"lyhenne":
+		forced_inflection_vtype = voikkoutils.VOWEL_DEFAULT
+	else:
+		inflectionElement = word.getElementsByTagName("inflection")
+		if len(inflectionElement) > 0:
+			forced_inflection_vtype = generate_lex_common.vowel_type(inflectionElement[0])
+		else:
+			forced_inflection_vtype = voikkoutils.VOWEL_DEFAULT
 	
-	# Construct debug information
-	debug_info = u""
+	# Construct debug information and additional attributes
+	additional_attributes = get_additional_attributes(word)
 	if OPTIONS["sourceid"]:
-		debug_info = u', sourceid: "%s"' % word.getAttribute("id")
+		additional_attributes = additional_attributes + u', sourceid: "%s"' % word.getAttribute("id")
 	
 	# Process all alternative forms
 	singlePartForms = []
@@ -110,23 +152,39 @@ def handle_word(word):
 		else:
 			multiPartForms.append(altform)
 		(alku, jatko) = generate_lex_common.get_malaga_inflection_class(wordform, voikko_infclass, wordclasses, CLASSMAP)
-		if forced_inflection_vtype == voikkoutils.VOWEL_DEFAULT:
-			vtype = voikkoutils.get_wordform_infl_vowel_type(altform)
-		else: vtype = forced_inflection_vtype
-		if vtype == voikkoutils.VOWEL_FRONT: malaga_vtype = u'ä'
-		elif vtype == voikkoutils.VOWEL_BACK: malaga_vtype = u'a'
-		elif vtype == voikkoutils.VOWEL_BOTH: malaga_vtype = u'aä'
-		rakenne = generate_lex_common.get_structure(altform, malaga_word_class)
 		if alku == None:
 			errorstr = u"ERROR: Malaga class not found for (%s, %s)\n" \
 				% (wordform, voikko_infclass)
 			generate_lex_common.write_entry(main_vocabulary, {}, word, errorstr)
 			sys.stderr.write(errorstr.encode(u"UTF-8"))
 			sys.exit(1)
-		entry = u'[perusmuoto: "%s", alku: "%s", luokka: %s, jatko: <%s>, äs: %s%s%s%s];' \
-		          % (wordform, alku, malaga_word_class, jatko, malaga_vtype, malaga_flags,
+		if malaga_word_class == u"lyhenne":
+			jatko = u"tavuviiva, kaksoispiste, loppu"
+		elif malaga_word_class == u"seikkasana":
+			jatko = get_adverb_jatko(word)
+		if malaga_word_class == u"etuliite":
+			vtype = voikkoutils.VOWEL_BOTH
+			malaga_jatko = get_prefix_jatko(word)
+		else:
+			if forced_inflection_vtype == voikkoutils.VOWEL_DEFAULT:
+				vtype = voikkoutils.get_wordform_infl_vowel_type(altform)
+			else:
+				vtype = forced_inflection_vtype
+			malaga_jatko = u"<" + jatko + u">"
+		if vtype == voikkoutils.VOWEL_FRONT: malaga_vtype = u'ä'
+		elif vtype == voikkoutils.VOWEL_BACK: malaga_vtype = u'a'
+		elif vtype == voikkoutils.VOWEL_BOTH: malaga_vtype = u'aä'
+		rakenne = generate_lex_common.get_structure(altform, malaga_word_class)
+		if baseform is None:
+			baseform = wordform
+		if malaga_word_class == u"lyhenne":
+			perusmuotoEntry = u""
+		else:
+			perusmuotoEntry = u'perusmuoto: "%s", ' % baseform
+		entry = u'[%salku: "%s", luokka: %s, jatko: %s, äs: %s%s%s%s];' \
+		          % (perusmuotoEntry, alku, malaga_word_class, malaga_jatko, malaga_vtype, malaga_flags,
 			   generate_lex_common.get_structure(altform, malaga_word_class),
-			   debug_info)
+			   additional_attributes)
 		generate_lex_common.write_entry(main_vocabulary, {}, word, entry)
 	
 	# Sanity check for alternative forms: if there are both multi part forms and single part forms
